@@ -5,6 +5,8 @@
 #define VECGEOM_BASE_BVH_H_
 
 #include "VecGeom/base/AABB.h"
+#include "VecGeom/base/Config.h"
+#include "VecGeom/base/Cuda.h"
 #include "VecGeom/navigation/NavStateIndex.h"
 #include "VecGeom/navigation/NavigationState.h"
 #include "VecGeom/volumes/LogicalVolume.h"
@@ -94,29 +96,30 @@ public:
   void CheckDaughterIntersections(Vector3D<Precision> localpoint, Vector3D<Precision> localdir, Precision &step,
                                   VPlacedVolume const *last, VPlacedVolume const *&hitcandidate) const
   {
-    unsigned int stack[BVH_MAX_DEPTH] = {0}, *ptr = &stack[1];
+    unsigned int stack[BVH_MAX_DEPTH], *ptr = &stack[1];
+    stack[0] = 0;
 
     /* Calculate and reuse inverse direction to save on divisions */
     Vector3D<Precision> invdir(1.0 / NonZero(localdir[0]), 1.0 / NonZero(localdir[1]), 1.0 / NonZero(localdir[2]));
 
     do {
-      unsigned int id = *--ptr; /* pop next node id to be checked from the stack */
+      const unsigned int id = *--ptr; /* pop next node id to be checked from the stack */
 
       if (fNChild[id] >= 0) {
         /* For leaf nodes, loop over children */
         for (int i = 0; i < fNChild[id]; ++i) {
-          int prim = fPrimId[fOffset[id] + i];
+          const int prim = fPrimId[fOffset[id] + i];
           /* Check AABB first, then the volume itself if needed */
           if (fAABBs[prim].IntersectInvDir(localpoint, invdir, step)) {
-            auto vol  = fLV.GetDaughters()[prim];
-            auto dist = vol->DistanceToIn(localpoint, localdir, step);
+            const auto vol  = fLV.GetDaughters()[prim];
+            const auto dist = vol->DistanceToIn(localpoint, localdir, step);
             /* If distance to current child is smaller than current step, update step and hitcandidate */
             if (dist < step && !(dist <= 0.0 && vol == last)) step = dist, hitcandidate = vol;
           }
         }
       } else {
-        unsigned int childL = 2 * id + 1;
-        unsigned int childR = 2 * id + 2;
+        const unsigned int childL = 2 * id + 1;
+        const unsigned int childR = 2 * id + 2;
 
         /* For internal nodes, check AABBs to know if we need to traverse left and right children */
         Precision tminL = kInfLength, tmaxL = -kInfLength, tminR = kInfLength, tmaxR = -kInfLength;
@@ -124,8 +127,8 @@ public:
         fNodes[childL].ComputeIntersectionInvDir(localpoint, invdir, tminL, tmaxL);
         fNodes[childR].ComputeIntersectionInvDir(localpoint, invdir, tminR, tmaxR);
 
-        bool traverseL = tminL <= tmaxL && tmaxL >= 0.0 && tminL < step;
-        bool traverseR = tminR <= tmaxR && tmaxR >= 0.0 && tminR < step;
+        const bool traverseL = tminL <= tmaxL && tmaxL >= 0.0 && tminL < step;
+        const bool traverseR = tminR <= tmaxR && tmaxR >= 0.0 && tminR < step;
 
         /*
          * If both left and right nodes need to be checked, check closest one first.
@@ -168,28 +171,29 @@ public:
   VECCORE_ATT_HOST_DEVICE
   Precision ComputeSafety(Vector3D<Precision> localpoint, Precision safety) const
   {
-    unsigned int stack[BVH_MAX_DEPTH] = {0}, *ptr = &stack[1];
+    unsigned int stack[BVH_MAX_DEPTH], *ptr = &stack[1];
+    stack[0] = 0;
 
     do {
-      unsigned int id = *--ptr;
+      const unsigned int id = *--ptr;
 
       if (fNChild[id] >= 0) {
         for (int i = 0; i < fNChild[id]; ++i) {
-          int prim = fPrimId[fOffset[id] + i];
+          const int prim = fPrimId[fOffset[id] + i];
           if (fAABBs[prim].Safety(localpoint) < safety) {
-            Precision dist = fLV.GetDaughters()[prim]->SafetyToIn(localpoint);
+            const Precision dist = fLV.GetDaughters()[prim]->SafetyToIn(localpoint);
             if (dist < safety) safety = dist;
           }
         }
       } else {
-        unsigned int childL = 2 * id + 1;
-        unsigned int childR = 2 * id + 2;
+        const unsigned int childL = 2 * id + 1;
+        const unsigned int childR = 2 * id + 2;
 
-        Precision safetyL = fNodes[childL].Safety(localpoint);
-        Precision safetyR = fNodes[childR].Safety(localpoint);
+        const Precision safetyL = fNodes[childL].Safety(localpoint);
+        const Precision safetyR = fNodes[childR].Safety(localpoint);
 
-        bool traverseL = safetyL < safety;
-        bool traverseR = safetyR < safety;
+        const bool traverseL = safetyL < safety;
+        const bool traverseR = safetyR < safety;
 
         if (safetyR < safetyL) {
           if (traverseR) *ptr++ = childR;
@@ -251,16 +255,17 @@ public:
   bool LevelLocate(VPlacedVolume const *exclvol, Vector3D<Precision> const &localpoint, VPlacedVolume const *&pvol,
                    Vector3D<Precision> &daughterlocalpoint) const
   {
-    unsigned int stack[BVH_MAX_DEPTH] = {0}, *ptr = &stack[1];
+    unsigned int stack[BVH_MAX_DEPTH], *ptr = &stack[1];
+    stack[0] = 0;
 
     do {
-      unsigned int id = *--ptr;
+      const unsigned int id = *--ptr;
 
       if (fNChild[id] >= 0) {
         for (int i = 0; i < fNChild[id]; ++i) {
-          int prim = fPrimId[fOffset[id] + i];
+          const int prim = fPrimId[fOffset[id] + i];
           if (fAABBs[prim].Contains(localpoint)) {
-            auto vol = fLV.GetDaughters()[prim];
+            const auto vol = fLV.GetDaughters()[prim];
             if (vol != exclvol && vol->Contains(localpoint, daughterlocalpoint)) {
               pvol = vol;
               return true;
@@ -268,10 +273,10 @@ public:
           }
         }
       } else {
-        unsigned int childL = 2 * id + 1;
+        const unsigned int childL = 2 * id + 1;
         if (fNodes[childL].Contains(localpoint)) *ptr++ = childL;
 
-        unsigned int childR = 2 * id + 2;
+        const unsigned int childR = 2 * id + 2;
         if (fNodes[childR].Contains(localpoint)) *ptr++ = childR;
       }
     } while (ptr > stack);
@@ -293,16 +298,17 @@ public:
                    Vector3D<Precision> const &localdirection, VPlacedVolume const *&pvol,
                    Vector3D<Precision> &daughterlocalpoint) const
   {
-    unsigned int stack[BVH_MAX_DEPTH] = {0}, *ptr = &stack[1];
+    unsigned int stack[BVH_MAX_DEPTH], *ptr = &stack[1];
+    stack[0] = 0;
 
     do {
-      unsigned int id = *--ptr;
+      const unsigned int id = *--ptr;
 
       if (fNChild[id] >= 0) {
         for (int i = 0; i < fNChild[id]; ++i) {
-          int prim = fPrimId[fOffset[id] + i];
+          const int prim = fPrimId[fOffset[id] + i];
           if (fAABBs[prim].Contains(localpoint)) {
-            auto v = fLV.GetDaughters()[prim];
+            const auto v = fLV.GetDaughters()[prim];
 
             if (v == exclvol) continue;
 
@@ -311,12 +317,13 @@ public:
             const auto p = T->Transform(localpoint);
 
             auto Entering = [&]() {
-              Vector3D<Precision> normal, dir = T->TransformDirection(localdirection);
+              const Vector3D<Precision> dir = T->TransformDirection(localdirection);
+              Vector3D<Precision> normal;
               u->Normal(p, normal);
               return Vector3D<Precision>::Dot(normal, dir) < 0.0;
             };
 
-            auto inside = u->Inside(p);
+            const auto inside = u->Inside(p);
 
             if (inside == kInside || (inside == kSurface && Entering())) {
               pvol = v, daughterlocalpoint = p;
@@ -325,10 +332,10 @@ public:
           }
         }
       } else {
-        unsigned int childL = 2 * id + 1;
+        const unsigned int childL = 2 * id + 1;
         if (fNodes[childL].Contains(localpoint)) *ptr++ = childL;
 
-        unsigned int childR = 2 * id + 2;
+        const unsigned int childR = 2 * id + 2;
         if (fNodes[childR].Contains(localpoint)) *ptr++ = childR;
       }
     } while (ptr > stack);
