@@ -61,12 +61,12 @@ public:
 #ifndef VECCORE_CUDA
   virtual VPlacedVolume const *ConvertToUnspecialized() const override;
 #ifdef VECGEOM_ROOT
-  virtual TGeoShape const *ConvertToRoot() const override;
+  virtual TGeoShape const *ConvertToRoot() const override { return GetUnplacedVolume()->ConvertToRoot(GetName()); }
 #endif
 #ifdef VECGEOM_GEANT4
-  virtual G4VSolid const *ConvertToGeant4() const override;
+  virtual G4VSolid const *ConvertToGeant4() const override { return GetUnplacedVolume()->ConvertToGeant4(GetName()); }
 #endif
-#endif // VECGEOM_TEST_BENCHMARK
+#endif // VECGEOM_CUDA
 
   Precision GetRmin1() const { return GetUnplacedVolume()->GetRmin1(); }
   Precision GetRmax1() const { return GetUnplacedVolume()->GetRmax1(); }
