@@ -84,7 +84,7 @@ void PointInCyclicalSector(UnplacedVolumeType const &volume, Real_v const &x, Re
 
   if (onSurfaceT) {
     // in this case, includeSurface is irrelevant
-    ret = (Abs(startCheck) <= kHalfTolerance) | (Abs(endCheck) <= kHalfTolerance);
+    ret = (Abs(startCheck) <= kHalfTolerance) || (Abs(endCheck) <= kHalfTolerance);
   } else {
     if (smallerthanpi) {
       if (includeSurface)
@@ -93,9 +93,9 @@ void PointInCyclicalSector(UnplacedVolumeType const &volume, Real_v const &x, Re
         ret = (startCheck >= kHalfTolerance) & (endCheck >= kHalfTolerance);
     } else {
       if (includeSurface)
-        ret = (startCheck >= -kHalfTolerance) | (endCheck >= -kHalfTolerance);
+        ret = (startCheck >= -kHalfTolerance) || (endCheck >= -kHalfTolerance);
       else
-        ret = (startCheck >= kHalfTolerance) | (endCheck >= kHalfTolerance);
+        ret = (startCheck >= kHalfTolerance) || (endCheck >= kHalfTolerance);
     }
   }
 }
@@ -701,7 +701,7 @@ struct TubeImplementation {
     // For points outside z-range, return -1
     Real_v distz = tube.fZ - Abs(point.z()); // avoid a division for now
     done |= distz < -kHalfTolerance;         // distance is already set to -1
-    //  if(vecCore::EarlyReturnAllowed() && vecCore::MaskFull(done)) return;
+    if (vecCore::EarlyReturnAllowed() && vecCore::MaskFull(done)) return;
 
     Real_v rsq   = point.x() * point.x() + point.y() * point.y();
     Real_v rdotn = dir.x() * point.x() + dir.y() * point.y();
@@ -721,7 +721,14 @@ struct TubeImplementation {
     }
 
     // TODO: add outside check for phi-sections here
+    if (checkPhiTreatment<tubeTypeT>(tube)) {
+      Bool_v completelyoutsidephi(false);
+      Bool_v completelyinsidephi(false);
+      tube.fPhiWedge.GenericKernelForContainsAndInside<Real_v, true>(point, completelyinsidephi, completelyoutsidephi);
 
+      done |= completelyoutsidephi;
+      if (vecCore::EarlyReturnAllowed() && vecCore::MaskFull(done)) return;
+    }
     // OK, since we're here, then distance must be non-negative, and the
     // smallest of possible intersections
     vecCore::MaskedAssign(distance, !done, Real_v(kInfLength));
@@ -950,8 +957,8 @@ struct TubeImplementation {
     }
 
     if (checkPhiTreatment<tubeTypeT>(tube)) {
-      Real_v safephi;
-      PhiPlaneSafety<Real_v, UnplacedStruct_t, tubeTypeT, true>(tube, point, safephi);
+      // Now using Wedge to calculate the SafetyToOut for a sector of a tube
+      Real_v safephi = tube.fPhiWedge.SafetyToOut<Real_v>(point);
       vecCore::MaskedAssign(safety, safephi < safety, safephi);
     }
   }
