@@ -9,14 +9,6 @@
 #include "VecGeom/volumes/Cone.h"
 #include "VecGeom/volumes/SpecializedCone.h"
 
-#if defined(VECGEOM_ROOT)
-#include "TGeoCone.h"
-#endif
-
-#if defined(VECGEOM_GEANT4)
-#include "G4Cons.hh"
-#endif
-
 namespace vecgeom {
 inline namespace VECGEOM_IMPL_NAMESPACE {
 
@@ -37,20 +29,6 @@ VPlacedVolume const *PlacedCone::ConvertToUnspecialized() const
   return new SimpleCone(GetLabel().c_str(), GetLogicalVolume(), GetTransformation());
 }
 
-#ifdef VECGEOM_ROOT
-TGeoShape const *PlacedCone::ConvertToRoot() const
-{
-  return GetUnplacedVolume()->ConvertToRoot(GetName());
-}
-#endif
-
-#ifdef VECGEOM_GEANT4
-G4VSolid const *PlacedCone::ConvertToGeant4() const
-{
-  return GetUnplacedVolume()->ConvertToGeant4(GetName());
-}
-#endif
-
 #endif
 
 } // namespace VECGEOM_IMPL_NAMESPACE
