@@ -7,10 +7,7 @@
 
 #include "VecGeom/volumes/PlacedEllipsoid.h"
 #include "VecGeom/volumes/SpecializedEllipsoid.h"
-#ifdef VECGEOM_ROOT
-// Include header file for ROOT Ellipsoid as done for Elliptical Tube below
-// #include "TGeoEltu.h"
-#endif
+
 #ifdef VECGEOM_GEANT4
 #include "G4Ellipsoid.hh"
 #endif
@@ -38,14 +35,6 @@ VPlacedVolume const *PlacedEllipsoid::ConvertToUnspecialized() const
   return new SimpleEllipsoid(GetLabel().c_str(), GetLogicalVolume(), GetTransformation());
 }
 
-#ifdef VECGEOM_ROOT
-TGeoShape const *PlacedEllipsoid::ConvertToRoot() const
-{
-  // Return ROOT Ellipsoid
-  return nullptr; // There is no suitable TGeo shape 2019.06.17
-}
-#endif
-
 #ifdef VECGEOM_GEANT4
 G4VSolid const *PlacedEllipsoid::ConvertToGeant4() const
 {
