@@ -8,14 +8,6 @@
 #include "VecGeom/volumes/SpecializedPolycone.h"
 #include <iostream>
 
-#ifdef VECGEOM_ROOT
-#include "TGeoPcon.h"
-#endif
-
-#ifdef VECGEOM_GEANT4
-#include "G4Polycone.hh"
-#endif
-
 namespace vecgeom {
 inline namespace VECGEOM_IMPL_NAMESPACE {
 
@@ -36,19 +28,6 @@ VPlacedVolume const *PlacedPolycone::ConvertToUnspecialized() const
   return new SimplePolycone(GetLabel().c_str(), GetLogicalVolume(), GetTransformation());
 }
 
-#ifdef VECGEOM_ROOT
-TGeoShape const *PlacedPolycone::ConvertToRoot() const
-{
-  return GetUnplacedVolume()->ConvertToRoot(GetName());
-}
-#endif
-
-#ifdef VECGEOM_GEANT4
-G4VSolid const *PlacedPolycone::ConvertToGeant4() const
-{
-  return GetUnplacedVolume()->ConvertToGeant4(GetName());
-}
-#endif
 #endif // ! VECCORE_CUDA
 } // namespace VECGEOM_IMPL_NAMESPACE
 
