@@ -1,6 +1,6 @@
-#include "ClangTidy.h"
-#include "ClangTidyModule.h"
-#include "ClangTidyModuleRegistry.h"
+#include <clang-tidy/ClangTidy.h>
+#include <clang-tidy/ClangTidyModule.h>
+#include <clang-tidy/ClangTidyModuleRegistry.h>
 #include "MaskedAssignCheck.h"
 
 namespace clang {
@@ -15,10 +15,10 @@ public:
   }
 };
 
-} // namespace vecgeom
-
 // Register the  using this statically initialized variable.
-static ClangTidyModuleRegistry::Add<vecgeom::VecGeomTidyModule> X("vecgeom-tidy-module", "Adds VecGeom specific checks");
+static ClangTidyModuleRegistry::Add<VecGeomTidyModule> X("vecgeom-module", "Adds VecGeom specific checks.");
+
+} // namespace vecgeom
 
 // This anchor is used to force the linker to link in the generated object file
 // and thus register the AliceO2Module.
@@ -26,15 +26,3 @@ volatile int VecGeomTidyModuleAnchorSource = 0;
 
 } // namespace tidy
 } // namespace clang
-
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wunused-function"
-
-// A function to execute upon load of shared library
-// will register this plugin will clang-tidy
-static int VecGeomTidyModule_sharedlib_init() {
-  static clang::tidy::vecgeom::VecGeomTidyModule module;
-  return clang::tidy::VecGeomTidyModuleAnchorSource;
-}
-
-#pragma clang diagnostic pop
