@@ -40,7 +40,7 @@
 #endif
 
 #ifdef VECGEOM_ROOT
-#include "utilities/Visualizer.h"
+#include "VecGeomTest/Visualizer.h"
 #include "TPolyMarker3D.h"
 #include "TPolyLine3D.h"
 #endif
