@@ -1,4 +1,4 @@
-#include "utilities/Visualizer.h"
+#include "VecGeomTest/Visualizer.h"
 #include "VecGeom/volumes/Paraboloid.h"
 #include "VecGeom/volumes/utilities/VolumeUtilities.h"
 #include "VecGeom/base/AOS3D.h"
